<?php
namespace App\Http\Controllers\Api\V1\Dashboard\Admin;
use App\Http\Actions\Admin\LoginAction;
use App\Http\Actions\Admin\RegisterAction;
use App\Http\Actions\Admin\UpdateAction;
use App\Http\Controllers\Controller;
use App\Http\Requests\Api\Admin\LoginRequest;
use App\Http\Requests\Api\Admin\RegisterRequest;
use App\Http\Requests\Api\Admin\UpdateRequest;
use App\Http\Resources\Api\V1\Admin\AdminResource;
use App\Http\Resources\Api\V1\Admin\AdminUpdateResource;
use App\Http\Resources\Api\V1\Admin\AllAdminCollection;
use App\Http\Resources\Api\V1\Admin\AllAdminResource;
use App\Models\Admin;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

class AdminController extends Controller
{
    public function login(LoginRequest $request):Response
    {
        return app(LoginAction::class)->handle($request->validated());
    }
    public function register(RegisterRequest $request):Response
    {
        return app(RegisterAction::class)->handle($request->validated());
    }
    /**
     * Display a listing of the resource.
     */
    public function index():Response
    {
        return apiResponse(  AllAdminCollection::make(Admin::paginate(10)),'is success Admin',true);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(RegisterRequest $request):Response
    {
        return app(RegisterAction::class)->handle($request->validated());
    }

    /**
     * Display the specified resource.
     */
    public function show(Admin $admin)
    {
        return apiResponse(  new AdminUpdateResource($admin),'is success Admin',true);
    }


    /**
     * Update the specified resource in storage.
     */
    public function update(UpdateRequest $request,Admin $admin){
       return app(UpdateAction::class)->handle($admin,$request->validated());
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Admin $admin=null)
    {
        $admin->delete();
        return apiResponse(  [],'is success Admin',true);
    }    
    
    public function getUserToken(Request $request):Response
    {
        return apiResponse(  new AdminUpdateResource($request->user()),'is success Admin',true);
    }
}