<?php

namespace App\Http\Controllers\Api\V1\Dashboard\Admin;

use App\Http\Actions\City\StoreCityAction;
use App\Http\Actions\City\UpdateCityAction;
use App\Http\Actions\Country\StoreCountryAction;
use App\Http\Actions\Country\UpdateCountryAction;
use App\Http\Controllers\Controller;
use App\Http\Requests\Api\Admin\City\CityStore;
use App\Http\Requests\Api\Admin\City\CityUpdate;
use App\Http\Requests\Api\Admin\Country\CountryStore;
use App\Http\Requests\Api\Admin\Country\CountryUpdate;
use App\Http\Resources\Api\V1\Admin\AllCityCollection;
use App\Http\Resources\Api\V1\Admin\CityResource;
use App\Http\Resources\Api\V1\Admin\CountryResource;
use App\Models\City;
use App\Models\Country;
use Illuminate\Http\Response;

class CityController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index():Response
    {
        return apiResponse(  AllCityCollection::make(City::paginate(10)),'is success City',true);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(CityStore $request):Response
    {
        return app(StoreCityAction::class)->handle($request->validated());
    }

    /**
     * Display the specified resource.
     */
    public function show(City $city=null):Response
    {
        if(!empty($city)){
            return apiResponse(  new CityResource($city),'is success City',true);
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(CityUpdate $request, City $city=null)
    {
       return app(UpdateCityAction::class)->handle($city,$request->validated());
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(City $city=null)
    {
        $city->delete();
        return apiResponse(  [],'is success City',true);
    }
}
