<?php

namespace App\Http\Controllers\Api\V1\Dashboard\Admin;

use App\Http\Actions\Country\StoreCountryAction;
use App\Http\Actions\Country\UpdateCountryAction;
use App\Http\Controllers\Controller;
use App\Http\Requests\Api\Admin\Country\CountryStore;
use App\Http\Requests\Api\Admin\Country\CountryUpdate;
use App\Http\Resources\Api\V1\Admin\AllCountryCollection;
use App\Http\Resources\Api\V1\Admin\CountryResource;
use App\Models\Country;
use Illuminate\Http\Response;

class CountryController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index():Response
    {
        return apiResponse(  AllCountryCollection::make(Country::paginate(10)),'is success Country',true);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(CountryStore $request):Response
    {
        return app(StoreCountryAction::class)->handle($request->validated());
    }

    /**
     * Display the specified resource.
     */
    public function show(Country $country=null):Response
    {
        if(!empty($country)){
            return apiResponse(  new CountryResource($country),'is success Country',true);
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(CountryUpdate $request, Country $country=null)
    {
       return app(UpdateCountryAction::class)->handle($country,$request->validated());
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Country $country=null)
    {
        $country->delete();
        return apiResponse(  [],'is success Country',true);
    }
}
