<?php

namespace App\Http\Controllers\Api\V1\Dashboard\Admin;

use App\Http\Actions\JobRecruitment\StoreJobRecruitmentAction;
use App\Http\Actions\JobRecruitment\UpdateJobRecruitmentAction;
use App\Http\Controllers\Controller;
use App\Http\Requests\Api\Admin\Country\CountryStore;
use App\Http\Requests\Api\Admin\Country\CountryUpdate;
use App\Http\Requests\Api\Admin\JobRecruitment\JobRecruitmentStore;
use App\Http\Requests\Api\Admin\JobRecruitment\JobRecruitmentUpdate;
use App\Http\Resources\Api\V1\Admin\AllCountryCollection;
use App\Http\Resources\Api\V1\Admin\CountryResource;
use App\Http\Resources\Api\V1\Admin\Recruitment\AllJobRecruitmentCollection;
use App\Http\Resources\Api\V1\Admin\Recruitment\JobRecruitmentResource;
use App\Models\Country;
use App\Models\JobRecruitment;
use Illuminate\Http\Response;

class JobRecruitmentController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index():Response
    {
        return apiResponse(  AllJobRecruitmentCollection::make(JobRecruitment::paginate(10)),'is success JobRecruitment',true);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(JobRecruitmentStore $request):Response
    {
        return app(StoreJobRecruitmentAction::class)->handle($request->validated());
    }

    /**
     * Display the specified resource.
     */
    public function show(JobRecruitment $jobRecruitment=null):Response
    {
        if(!empty($jobRecruitment)){
            return apiResponse(  new JobRecruitmentResource($jobRecruitment),'is success JobRecruitment',true);
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(JobRecruitmentUpdate $request, JobRecruitment $jobRecruitment=null)
    {
       return app(UpdateJobRecruitmentAction::class)->handle($jobRecruitment,$request->validated());
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(JobRecruitment $jobRecruitment=null)
    {
        $jobRecruitment->delete();
        return apiResponse(  [],'is success JobRecruitment',true);
    }
}
