<?php

namespace App\Http\Controllers\Api\V1\Dashboard\Admin;

use App\Http\Actions\JobServices\StoreJobServicesAction;
use App\Http\Actions\JobServices\UpdateJobServicesAction;
use App\Http\Controllers\Controller;
use App\Http\Requests\Api\Admin\JobServices\JobServicesStore;
use App\Http\Requests\Api\Admin\JobServices\JobServicesUpdate;
use App\Http\Resources\Api\V1\Admin\Services\AllJobServicesCollection;
use App\Http\Resources\Api\V1\Admin\Services\JobServicesResource;
use App\Models\Country;
use App\Models\JobServices;
use Illuminate\Http\Response;

class JobServicesController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index():Response
    {
        return apiResponse(  AllJobServicesCollection::make(JobServices::paginate(10)),'is success JobServices',true);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(JobServicesStore $request):Response
    {
        return app(StoreJobServicesAction::class)->handle($request->validated());
    }

    /**
     * Display the specified resource.
     */
    public function show(JobServices $job_service=null):Response
    {
        if(!empty($job_service)){
            return apiResponse(  new JobServicesResource($job_service),'is success JobServices',true);
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(JobServicesUpdate $request, JobServices $job_service=null)
    {
       return app(UpdateJobServicesAction::class)->handle($job_service,$request->validated());
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(JobServices $job_service=null)
    {
        $job_service->delete();
        return apiResponse(  [],'is success JobServices',true);
    }
}
