<?php
namespace App\Http\Controllers\Api\V1\Dashboard\Vendor;


use App\Http\Actions\Country\StoreCountryAction;
use App\Http\Actions\Country\UpdateCountryAction;
use App\Http\Actions\JobRecruitment\StoreJobRecruitmentAction;
use App\Http\Actions\JobRecruitment\UpdateJobRecruitmentAction;
use App\Http\Actions\Recruitment\StoreRecruitmentAction;
use App\Http\Actions\Recruitment\UpdateRecruitmentAction;
use App\Http\Controllers\Controller;
use App\Http\Requests\Api\Admin\Country\CountryStore;
use App\Http\Requests\Api\Admin\Country\CountryUpdate;
use App\Http\Requests\Api\Admin\JobRecruitment\JobRecruitmentStore;
use App\Http\Requests\Api\Admin\JobRecruitment\JobRecruitmentUpdate;
use App\Http\Requests\Api\Vendor\Recruitment\RecruitmentStore;
use App\Http\Requests\Api\Vendor\Recruitment\RecruitmentUpdate;
use App\Http\Resources\Api\V1\Admin\AllCountryCollection;
use App\Http\Resources\Api\V1\Admin\CountryResource;
use App\Http\Resources\Api\V1\Admin\Recruitment\AllJobRecruitmentCollection;
use App\Http\Resources\Api\V1\Admin\Recruitment\JobRecruitmentResource;
use App\Http\Resources\Api\V1\Vendor\Recruitment\AllRecruitmentCollection;
use App\Http\Resources\Api\V1\Vendor\Recruitment\RecruitmentResource;
use App\Models\Country;
use App\Models\JobRecruitment;
use App\Models\Recruitment;
use Illuminate\Http\Response;

class RecruitmentController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index():Response
    {
        return apiResponse(  AllRecruitmentCollection::make(Recruitment::paginate(10)),'is success recruitment',true);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(RecruitmentStore $request):Response
    {
        return app(StoreRecruitmentAction::class)->handle($request->validated());
    }

    /**
     * Display the specified resource.
     */
    public function show(Recruitment $recruitment=null):Response
    {
        if(!empty($recruitment)){
            return apiResponse(  new RecruitmentResource($recruitment),'is success recruitment',true);
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(RecruitmentUpdate $request, Recruitment $recruitment=null)
    {
       return app(UpdateRecruitmentAction::class)->handle($recruitment,$request->validated());
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Recruitment $recruitment=null)
    {
        $recruitment->delete();
        return apiResponse(  [],'is success recruitment',true);
    }
}
