<?php
namespace App\Http\Controllers\Api\V1\Dashboard\Vendor;


use App\Http\Actions\Country\StoreCountryAction;
use App\Http\Actions\Country\UpdateCountryAction;
use App\Http\Actions\JobRecruitment\StoreJobRecruitmentAction;
use App\Http\Actions\JobRecruitment\UpdateJobRecruitmentAction;
use App\Http\Actions\Recruitment\StoreRecruitmentAction;
use App\Http\Actions\Recruitment\UpdateRecruitmentAction;
use App\Http\Actions\Services\StoreServicesAction;
use App\Http\Actions\Services\UpdateServicesAction;
use App\Http\Controllers\Controller;
use App\Http\Requests\Api\Admin\Country\CountryStore;
use App\Http\Requests\Api\Admin\Country\CountryUpdate;
use App\Http\Requests\Api\Admin\JobRecruitment\JobRecruitmentStore;
use App\Http\Requests\Api\Admin\JobRecruitment\JobRecruitmentUpdate;
use App\Http\Requests\Api\Vendor\Recruitment\RecruitmentStore;
use App\Http\Requests\Api\Vendor\Recruitment\RecruitmentUpdate;
use App\Http\Requests\Api\Vendor\Services\ServicesStore;
use App\Http\Requests\Api\Vendor\Services\ServicesUpdate;
use App\Http\Resources\Api\V1\Vendor\Recruitment\AllRecruitmentCollection;
use App\Http\Resources\Api\V1\Vendor\Recruitment\RecruitmentResource;
use App\Http\Resources\Api\V1\Vendor\Services\AllServicesCollection;
use App\Http\Resources\Api\V1\Vendor\Services\ServicesResource;
use App\Models\Country;
use App\Models\JobRecruitment;
use App\Models\Recruitment;
use App\Models\Services;
use Illuminate\Http\Response;

class ServicesController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index():Response
    {
        return apiResponse(  AllServicesCollection::make(Services::paginate(10)),'is success Services',true);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(ServicesStore $request):Response
    {
        return app(StoreServicesAction::class)->handle($request->validated());
    }

    /**
     * Display the specified resource.
     */
    public function show(Services $service=null):Response
    {
        if(!empty($service)){
            return apiResponse(  new ServicesResource($service),'is success Services',true);
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(ServicesUpdate $request, Services $service=null)
    {
       return app(UpdateServicesAction::class)->handle($service,$request->validated());
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Services $service=null)
    {
        $service->delete();
        return apiResponse(  [],'is success services',true);
    }
}
