<?php
namespace App\Http\Requests\Api\Vendor\Recruitment;


use App\Enum\GeneralEnum;
use App\Enum\LanguageEnum;
use App\Enum\MartialStatusEnum;
use App\Enum\ReligionEnum;
use App\Enum\StatusEnum;
use App\Http\Requests\Api\BasicBridge;
use Illuminate\Validation\Rules\Enum;

class RecruitmentStore extends BasicBridge
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array
    {
        return [
            'reference'=>['nullable','unique:recruitments'],
            'general' => ['required','string','min:2','max:600' ,new Enum(GeneralEnum::class)],
            'job_id'=>'required|exists:job_recruitments,id',
            'contract_period'=>['required','integer','max:600'],
            'full_name.en'=>['required','string','min:2','max:600'],
            'full_name.ar'=>['required','string','min:2','max:600'],
            'nationality_id'=>'required|exists:countries,id',
            'religion'=>['required','string','min:2','max:600' ,new Enum(ReligionEnum::class)],
            'date_of_birth'=>['required','date'],
            'age'=>['required','integer'],
                // details of applicant
            'place_of_birth.en'=>['required','string','min:2','max:600'],
            'place_of_birth.ar'=>['required','string','min:2','max:600'],
            'living_town.en'=>['required','string','min:2','max:600'],
            'living_town.ar'=>['required','string','min:2','max:600'],
            'martial_status'=>['required','string','min:2','max:600',new Enum(MartialStatusEnum::class)],
            'no_of_children'=>['required','integer','max:600'],
            'weight'=>['required','integer','max:600'],
            'height'=>['required','numeric','max:600'],
            'complexion.en'=>['required','string','min:2','max:600'],
            'complexion.ar'=>['required','string','min:2','max:600'],
            'educational_qualifications_grade'=>['required','integer','max:600'],
                // knowledge of languages
            'language_arabic'=>['required','string','min:2','max:600',new Enum(LanguageEnum::class)],
            'language_english'=>['required','string','min:2','max:600',new Enum(LanguageEnum::class)],
                // previous employment abroad
            'previous_employment_abroad_country.en'=>['required','string','min:2','max:600'],
            'previous_employment_abroad_country.ar'=>['required','string','min:2','max:600'],       
            'previous_employment_abroad_period'=>['required','integer','max:600'],
                // work experience
            'work_experience.en'=>['required','string','min:2','max:600'],
            'work_experience.ar'=>['required','string','min:2','max:600'],                   
                // passport details
            'number_passport'=>['required','string','unique:recruitments','min:2','max:600'],

            'date_of_issue_passport'=>['required','date'],
            'place_of_issue_passport.en'=>['required','string','min:2','max:600'],
            'place_of_issue_passport.ar'=>['required','string','min:2','max:600'],       
            
            'date_of_expiry_passport'=>['required','date'],
            'status'=>['required',new Enum(StatusEnum::class)],
            'image'=>['required']
        ];
    }
}
