<?php

namespace App\Models;

use App\Models\City;
use App\Models\Country;
use App\Models\Services;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\Translatable\HasTranslations;

class Vendor extends Authenticatable implements HasMedia
{
    use HasFactory, Notifiable , InteractsWithMedia, HasApiTokens ,SoftDeletes,HasTranslations;
    
    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
     public $translatable = ['name'];
    protected $fillable = [
        'name',
        'email',
        'approval',
        'status',
        'type',
        'phone',
        'landline',
        'password',
        'country_id',
        'city_id',
    ]; 
    
   public function scopeSearch($query)
   {
        $search = Request()->query('search');
        if(empty($search)){
        return $query->orderBy('id','DESC')->paginate(5);
        }else{
        return
         $query
        ->orWhere('name', 'like' , "%{$search}%")
        ->orWhere('email', 'like' , "%{$search}%")
        ->orWhere('phone', 'like' , "%{$search}%")
        ->orderBy('id','DESC')->paginate(5);
        }
   }
   
    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array
    {
        return [
            'email_verified_at' => 'datetime',
            'password' => 'hashed',
        ];
    }
    
    public function Recruitment()
    {
        return $this->hasMany(Recruitment::class,'vendor_id')->where('status','1');
    }          
    
    public function Services()
    {
        return $this->hasMany(Services::class,'vendor_id')->where('status','1');
    }         
    public function Country()
    {
        return $this->belongsTo(Country::class,'country_id');
    }     
    public function City()
    {
        return $this->belongsTo(City::class,'city_id');
    }        
}
