<?php

use App\Enum\GeneralEnum;
use App\Enum\LanguageEnum;
use App\Enum\MartialStatusEnum;
use App\Enum\ReligionEnum;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('recruitments', function (Blueprint $table) {
            $table->id();
            $table->string('reference');
            $table->enum('general', array_column(GeneralEnum::cases(), 'value'));
            $table->foreignId('vendor_id')->constrained('vendors')->cascadeOnDelete()->cascadeOnUpdate();
            $table->foreignId('job_id')->constrained('job_recruitments')->cascadeOnDelete()->cascadeOnUpdate();
            $table->integer('contract_period');
            $table->string('full_name');
            // details of applicant
            $table->foreignId('nationality_id')->constrained('countries')->cascadeOnDelete()->cascadeOnUpdate();
            $table->enum('religion', array_column(ReligionEnum::cases(), 'value'));
            $table->date('date_of_birth');
            $table->integer('age');
            $table->string('place_of_birth');
            $table->string('living_town');
            $table->enum('martial_status', array_column(MartialStatusEnum::cases(), 'value'));
            $table->integer('no_of_children');
            $table->integer('weight');
            $table->decimal('height');
            $table->string('complexion');
            $table->integer('educational_qualifications_grade');
            // knowledge of languages
            $table->enum('language_arabic', array_column(LanguageEnum::cases(), 'value'));
            $table->enum('language_english', array_column(LanguageEnum::cases(), 'value'));
            // previous employment abroad
            $table->string('previous_employment_abroad_country');
            $table->integer('previous_employment_abroad_period');
            // work experience
            $table->json('work_experience');
            // passport details
            $table->string('number_passport');
            $table->date('date_of_issue_passport');
            $table->string('place_of_issue_passport');
            $table->date('date_of_expiry_passport');
            $table->boolean('status')->default('1');
            $table->softDeletes(); // <-- This will add a deleted_at field
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('recruitments');
    }
};